import numpy as np
import sys
import homcloud.interface as hc
from scipy.spatial import distance_matrix


def main():
    if sys.argv[1] == "generate-data":
        n = int(sys.argv[2])
        generate_data(n)
    elif sys.argv[1] == "compute-pd":
        n = int(sys.argv[2])
        maxdim = int(sys.argv[3])
        compute_pd(n, maxdim)
    elif sys.argv[1] == "optimal-1-cycle":
        optimal_1_cycle(int(sys.argv[2]), *map(float, sys.argv[3:]))
    
def data_path(n):
    return f"data_{n}.npy"


def pdgm_path(n):
    return f"data_{n}.pdgm"


def generate_data(n):
    pc = np.random.uniform(-1.0, 1.0, (n, 10))
    dmatrix = distance_matrix(pc, pc)
    np.savetxt(data_path(n), dmatrix)


def compute_pd(n, maxdim):
    hc.PDList.from_rips_filtration(np.loadtxt(data_path(n), dtype=np.float32),
                                   maxdim, save_graph=True, save_to=pdgm_path(n))
                                   


def optimal_1_cycle(n, x, y):
    pd1 = hc.PDList(pdgm_path(n)).dth_diagram(1)
    pair = pd1.nearest_pair_to(x, y)
    print(pair)
    print(pair.optimal_1_cycle().boundary_points())


main()
